#使用turtle画一个篮球形状
import turtle
import math
turtle.showturtle
import math
turtle.pensize(3)
turtle.color("brown")
turtle.circle(50)
a=0
x=50
turtle.left(45)
turtle.circle(60,110)
turtle.penup()
turtle.goto(-50,50)
turtle.pendown()
turtle.left(180)
turtle.circle(90,66)
turtle.penup()
turtle.goto(-25,10)
turtle.pendown()
turtle.left(26)
turtle.circle(50,80)
turtle.penup()
turtle.goto(40,80)
turtle.right(-110)
turtle.pendown()
turtle.circle(90,35)
turtle.penup()
turtle.goto(0,-90)
turtle.done()


#coding=utf-8
from distutils.core import setup

setup(
    name='lanqiu',#模块的名字叫篮球的中文拼音
    version='1.0',#版本号，虽然我不确定还有第二版，嘿嘿！
    description='这是我第一个发布的模块，里面只是一个球的图案,勿喷哦',#内容描述
    author='Mr.wang',#全名就不告诉你。嘿嘿！
    author_email='174984428@qq.com',#还好我有个邮箱。
    py_modules=['basketball.lanqiu'],#好啦,就是篮球啦
)